@@ -21,7 +21,6 @@
 
 #include "rtrlib/transport/transport.h"
 
-
 /**
  * @brief  A tr_tcp_config struct holds configuration for a TCP connection.
  * @param host Hostname or IP address to connect to.
@@ -29,11 +28,23 @@
  * @param bindaddr Hostname or IP address to connect from. NULL for
  *		   determination by OS.
  * to use the source address of the system's default route to the server
+ * @param data Information to pass to callback function
+ *	  in charge of retrieving socket
+ * @param new_socket(void *opaque_info) callback routine, that
+ *	  Pointer to the function that is called every time a new connection
+ *	  is made. The returned socket is expected to be ready for use (e.g.
+ *	  in state established), and must use a reliably stream-oriented transport.
+ *	  When new_socket() is used, host, port, and bindaddr are not used.
+ * @param connect_timeout Time in seconds to wait for a successful connection.
+ *	  Defaults to #RTRLIB_TRANSPORT_CONNECT_TIMEOUT_DEFAULT
  */
 struct tr_tcp_config {
-    char *host;
-    char *port;
-    char *bindaddr;
+	char *host;
+	char *port;
+	char *bindaddr;
+	void *data;
+	int (*new_socket)(void *data);
+	unsigned int connect_timeout;
 };
 
 /**
@@ -45,4 +56,4 @@ struct tr_tcp_config {
  */
 int tr_tcp_init(const struct tr_tcp_config *config, struct tr_socket *socket);
 #endif
-/* @} */
+/** @} */
