@@ -7,11 +7,12 @@
  * Website; http://rtrlib.realmv6.org/
  */
 
+#include "rtrlib_unittests.h"
+#include "test_packets_static.h"
+
 #include "rtrlib/lib/alloc_utils_private.h"
 #include "rtrlib/rtr/packets.c"
 #include "rtrlib/rtr_mgr_private.h"
-#include "rtrlib_unittests.h"
-#include "test_packets_static.h"
 
 int __wrap_lrtr_get_monotonic_time(time_t *seconds)
 {
@@ -19,9 +20,7 @@ int __wrap_lrtr_get_monotonic_time(time_t *seconds)
 	return mock_type(int);
 }
 
-int __wrap_tr_send_all(const struct tr_socket *socket,
-		       const void *pdu, const size_t len,
-		       const time_t timeout)
+int __wrap_tr_send_all(const struct tr_socket *socket, const void *pdu, const size_t len, const time_t timeout)
 {
 	check_expected(socket);
 	check_expected(pdu);
@@ -30,20 +29,14 @@ int __wrap_tr_send_all(const struct tr_socket *socket,
 	return (int)mock();
 }
 
-static int cmp_serial_in_error_pdu(const LargestIntegralType test,
-				   const LargestIntegralType reference)
+static int cmp_serial_in_error_pdu(const LargestIntegralType test, const LargestIntegralType reference)
 {
-	struct pdu_error *test_pdu =
-		(struct pdu_error *)test;
-	struct pdu_serial_query *reference_pdu =
-		(struct pdu_serial_query *)reference;
-	struct pdu_serial_query *encapsulated_pdu =
-		(struct pdu_serial_query *)test_pdu->rest;
+	struct pdu_error *test_pdu = (struct pdu_error *)test;
+	struct pdu_serial_query *reference_pdu = (struct pdu_serial_query *)reference;
+	struct pdu_serial_query *encapsulated_pdu = (struct pdu_serial_query *)test_pdu->rest;
 
-	if (encapsulated_pdu->ver != reference_pdu->ver ||
-	    encapsulated_pdu->type != reference_pdu->type ||
-	    encapsulated_pdu->session_id != reference_pdu->session_id ||
-	    encapsulated_pdu->len != reference_pdu->len ||
+	if (encapsulated_pdu->ver != reference_pdu->ver || encapsulated_pdu->type != reference_pdu->type ||
+	    encapsulated_pdu->session_id != reference_pdu->session_id || encapsulated_pdu->len != reference_pdu->len ||
 	    encapsulated_pdu->sn != reference_pdu->sn) {
 		return 0;
 	}
@@ -51,20 +44,14 @@ static int cmp_serial_in_error_pdu(const LargestIntegralType test,
 	return 1;
 }
 
-static int cmp_header_in_error_pdu(const LargestIntegralType test,
-				   const LargestIntegralType reference)
+static int cmp_header_in_error_pdu(const LargestIntegralType test, const LargestIntegralType reference)
 {
-	struct pdu_error *test_pdu =
-		(struct pdu_error *)test;
-	struct pdu_serial_query *reference_pdu =
-		(struct pdu_serial_query *)reference;
-	struct pdu_serial_query *encapsulated_pdu =
-		(struct pdu_serial_query *)test_pdu->rest;
+	struct pdu_error *test_pdu = (struct pdu_error *)test;
+	struct pdu_serial_query *reference_pdu = (struct pdu_serial_query *)reference;
+	struct pdu_serial_query *encapsulated_pdu = (struct pdu_serial_query *)test_pdu->rest;
 
-	if (encapsulated_pdu->ver != reference_pdu->ver ||
-	    encapsulated_pdu->type != reference_pdu->type ||
-	    encapsulated_pdu->session_id != reference_pdu->session_id ||
-	    encapsulated_pdu->len != reference_pdu->len) {
+	if (encapsulated_pdu->ver != reference_pdu->ver || encapsulated_pdu->type != reference_pdu->type ||
+	    encapsulated_pdu->session_id != reference_pdu->session_id || encapsulated_pdu->len != reference_pdu->len) {
 		return 0;
 	}
 
@@ -287,71 +274,37 @@ static void test_rtr_send_error_pdu(void **state)
 	pdu_serial.len = sizeof(struct pdu_serial_query);
 	pdu_serial.sn = 0xDF;
 
-	memcpy(&pdu_serial_network,
-	       &pdu_serial,
-	       sizeof(struct pdu_serial_query));
+	memcpy(&pdu_serial_network, &pdu_serial, sizeof(struct pdu_serial_query));
 	rtr_pdu_to_network_byte_order(&pdu_serial_network);
 
 	expect_any_count(__wrap_tr_send_all, socket, 1);
 	expect_any_count(__wrap_tr_send_all, len, 1);
 	expect_any_count(__wrap_tr_send_all, timeout, 1);
-	expect_check(__wrap_tr_send_all,
-		     pdu,
-		     cmp_serial_in_error_pdu,
-		     &pdu_serial_network);
-	will_return(__wrap_tr_send_all,
-		    sizeof(pdu_serial) + sizeof(struct pdu_error));
+	expect_check(__wrap_tr_send_all, pdu, cmp_serial_in_error_pdu, &pdu_serial_network);
+	will_return(__wrap_tr_send_all, sizeof(pdu_serial) + sizeof(struct pdu_error));
 
-	ret = rtr_send_error_pdu_from_host(&socket,
-					   &pdu_serial,
-					   pdu_serial.len,
-					   INTERNAL_ERROR,
-					   NULL,
-					   0);
+	ret = rtr_send_error_pdu_from_host(&socket, &pdu_serial, pdu_serial.len, INTERNAL_ERROR, NULL, 0);
 	assert_int_equal(ret, RTR_SUCCESS);
 
 	expect_any_count(__wrap_tr_send_all, socket, 1);
 	expect_any_count(__wrap_tr_send_all, len, 1);
 	expect_any_count(__wrap_tr_send_all, timeout, 1);
-	expect_check(__wrap_tr_send_all,
-		     pdu,
-		     cmp_serial_in_error_pdu,
-		     &pdu_serial_network);
-	will_return(__wrap_tr_send_all,
-		    sizeof(pdu_serial_network) + sizeof(struct pdu_error));
+	expect_check(__wrap_tr_send_all, pdu, cmp_serial_in_error_pdu, &pdu_serial_network);
+	will_return(__wrap_tr_send_all, sizeof(pdu_serial_network) + sizeof(struct pdu_error));
 
-	ret = rtr_send_error_pdu_from_network(&socket,
-					      &pdu_serial_network,
-					      pdu_serial.len,
-					      INTERNAL_ERROR,
-					      NULL,
-					      0);
+	ret = rtr_send_error_pdu_from_network(&socket, &pdu_serial_network, pdu_serial.len, INTERNAL_ERROR, NULL, 0);
 	assert_int_equal(ret, RTR_SUCCESS);
 
 	expect_any_count(__wrap_tr_send_all, socket, 1);
 	expect_any_count(__wrap_tr_send_all, len, 1);
 	expect_any_count(__wrap_tr_send_all, timeout, 1);
-	expect_check(__wrap_tr_send_all,
-		     pdu,
-		     cmp_header_in_error_pdu,
-		     &pdu_serial_network);
-	will_return(__wrap_tr_send_all,
-		    sizeof(pdu_serial) + sizeof(struct pdu_error));
+	expect_check(__wrap_tr_send_all, pdu, cmp_header_in_error_pdu, &pdu_serial_network);
+	will_return(__wrap_tr_send_all, sizeof(pdu_serial) + sizeof(struct pdu_error));
 
-	ret = rtr_send_error_pdu_from_host(&socket,
-					   &pdu_serial,
-					   sizeof(struct pdu_header),
-					   INTERNAL_ERROR,
-					   NULL,
-					   0);
+	ret = rtr_send_error_pdu_from_host(&socket, &pdu_serial, sizeof(struct pdu_header), INTERNAL_ERROR, NULL, 0);
 	assert_int_equal(ret, RTR_SUCCESS);
 
-	ret = rtr_send_error_pdu_from_host(&socket,
-					   &pdu_serial,
-					   2,
-					   INTERNAL_ERROR,
-					   NULL,
-					   0);
+	ret = rtr_send_error_pdu_from_host(&socket, &pdu_serial, 2, INTERNAL_ERROR, NULL, 0);
 	assert_int_equal(ret, RTR_ERROR);
 }
 
@@ -373,37 +326,23 @@ static void test_rtr_pdu_check_interval(void **state)
 	pdu_eod.expire_interval = 601;
 
 	/* test appliance of interval values to the rtr_socket */
-	apply_interval_value(
-			&rtr_socket,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
-	assert_int_equal(rtr_socket.refresh_interval,
-			 pdu_eod.refresh_interval);
+	apply_interval_value(&rtr_socket, pdu_eod.refresh_interval, RTR_INTERVAL_TYPE_REFRESH);
+	assert_int_equal(rtr_socket.refresh_interval, pdu_eod.refresh_interval);
 
-	apply_interval_value(
-			&rtr_socket,
-			pdu_eod.retry_interval,
-			RTR_INTERVAL_TYPE_RETRY);
+	apply_interval_value(&rtr_socket, pdu_eod.retry_interval, RTR_INTERVAL_TYPE_RETRY);
 	assert_int_equal(rtr_socket.retry_interval, pdu_eod.retry_interval);
 
-	apply_interval_value(
-			&rtr_socket,
-			pdu_eod.expire_interval,
-			RTR_INTERVAL_TYPE_EXPIRATION);
+	apply_interval_value(&rtr_socket, pdu_eod.expire_interval, RTR_INTERVAL_TYPE_EXPIRATION);
 	assert_int_equal(rtr_socket.expire_interval, pdu_eod.expire_interval);
 
 	/* test checks that determine if value is inside range */
-	retval = rtr_check_interval_range(pdu_eod.refresh_interval,
-					  RTR_REFRESH_MIN, RTR_REFRESH_MAX);
+	retval = rtr_check_interval_range(pdu_eod.refresh_interval, RTR_REFRESH_MIN, RTR_REFRESH_MAX);
 	assert_int_equal(retval, RTR_INSIDE_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.retry_interval,
-					  RTR_RETRY_MIN, RTR_RETRY_MAX);
+	retval = rtr_check_interval_range(pdu_eod.retry_interval, RTR_RETRY_MIN, RTR_RETRY_MAX);
 	assert_int_equal(retval, RTR_INSIDE_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.expire_interval,
-					  RTR_EXPIRATION_MIN,
-					  RTR_EXPIRATION_MAX);
+	retval = rtr_check_interval_range(pdu_eod.expire_interval, RTR_EXPIRATION_MIN, RTR_EXPIRATION_MAX);
 	assert_int_equal(retval, RTR_INSIDE_INTERVAL_RANGE);
 
 	/* test checks that determine if value is below range */
@@ -411,17 +350,13 @@ static void test_rtr_pdu_check_interval(void **state)
 	pdu_eod.retry_interval = RTR_RETRY_MIN - 1;
 	pdu_eod.expire_interval = RTR_EXPIRATION_MIN - 1;
 
-	retval = rtr_check_interval_range(pdu_eod.refresh_interval,
-					  RTR_REFRESH_MIN, RTR_REFRESH_MAX);
+	retval = rtr_check_interval_range(pdu_eod.refresh_interval, RTR_REFRESH_MIN, RTR_REFRESH_MAX);
 	assert_int_equal(retval, RTR_BELOW_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.retry_interval,
-					  RTR_RETRY_MIN, RTR_RETRY_MAX);
+	retval = rtr_check_interval_range(pdu_eod.retry_interval, RTR_RETRY_MIN, RTR_RETRY_MAX);
 	assert_int_equal(retval, RTR_BELOW_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.expire_interval,
-					  RTR_EXPIRATION_MIN,
-					  RTR_EXPIRATION_MAX);
+	retval = rtr_check_interval_range(pdu_eod.expire_interval, RTR_EXPIRATION_MIN, RTR_EXPIRATION_MAX);
 	assert_int_equal(retval, RTR_BELOW_INTERVAL_RANGE);
 
 	/* test checks that determine if value is above range */
@@ -429,68 +364,48 @@ static void test_rtr_pdu_check_interval(void **state)
 	pdu_eod.retry_interval = RTR_RETRY_MAX + 1;
 	pdu_eod.expire_interval = RTR_EXPIRATION_MAX + 1;
 
-	retval = rtr_check_interval_range(pdu_eod.refresh_interval,
-					  RTR_REFRESH_MIN, RTR_REFRESH_MAX);
+	retval = rtr_check_interval_range(pdu_eod.refresh_interval, RTR_REFRESH_MIN, RTR_REFRESH_MAX);
 	assert_int_equal(retval, RTR_ABOVE_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.retry_interval,
-					  RTR_RETRY_MIN, RTR_RETRY_MAX);
+	retval = rtr_check_interval_range(pdu_eod.retry_interval, RTR_RETRY_MIN, RTR_RETRY_MAX);
 	assert_int_equal(retval, RTR_ABOVE_INTERVAL_RANGE);
 
-	retval = rtr_check_interval_range(pdu_eod.expire_interval,
-					  RTR_EXPIRATION_MIN,
-					  RTR_EXPIRATION_MAX);
+	retval = rtr_check_interval_range(pdu_eod.expire_interval, RTR_EXPIRATION_MIN, RTR_EXPIRATION_MAX);
 	assert_int_equal(retval, RTR_ABOVE_INTERVAL_RANGE);
 
 	/* test the different interval options the user can choose */
 	rtr_socket.refresh_interval = 0;
 	pdu_eod.refresh_interval = 42;
-	retval = rtr_check_interval_option(
-			&rtr_socket,
-			RTR_INTERVAL_MODE_ACCEPT_ANY,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
+	retval = rtr_check_interval_option(&rtr_socket, RTR_INTERVAL_MODE_ACCEPT_ANY, pdu_eod.refresh_interval,
+					   RTR_INTERVAL_TYPE_REFRESH);
 	assert_int_equal(retval, RTR_SUCCESS);
-	assert_int_equal(rtr_socket.refresh_interval,
-			 pdu_eod.refresh_interval);
+	assert_int_equal(rtr_socket.refresh_interval, pdu_eod.refresh_interval);
 
 	rtr_socket.refresh_interval = 0;
 	pdu_eod.refresh_interval = RTR_REFRESH_MAX + 1;
-	retval = rtr_check_interval_option(
-			&rtr_socket,
-			RTR_INTERVAL_MODE_DEFAULT_MIN_MAX,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
+	retval = rtr_check_interval_option(&rtr_socket, RTR_INTERVAL_MODE_DEFAULT_MIN_MAX, pdu_eod.refresh_interval,
+					   RTR_INTERVAL_TYPE_REFRESH);
 	assert_int_equal(retval, RTR_SUCCESS);
 	assert_int_equal(rtr_socket.refresh_interval, RTR_REFRESH_MAX);
 
 	rtr_socket.refresh_interval = 0;
 	pdu_eod.refresh_interval = RTR_REFRESH_MIN - 1;
-	retval = rtr_check_interval_option(
-			&rtr_socket,
-			RTR_INTERVAL_MODE_DEFAULT_MIN_MAX,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
+	retval = rtr_check_interval_option(&rtr_socket, RTR_INTERVAL_MODE_DEFAULT_MIN_MAX, pdu_eod.refresh_interval,
+					   RTR_INTERVAL_TYPE_REFRESH);
 	assert_int_equal(retval, RTR_SUCCESS);
 	assert_int_equal(rtr_socket.refresh_interval, RTR_REFRESH_MIN);
 
 	rtr_socket.refresh_interval = 42;
 	pdu_eod.refresh_interval = RTR_REFRESH_MIN - 1;
-	retval = rtr_check_interval_option(
-			&rtr_socket,
-			RTR_INTERVAL_MODE_IGNORE_ON_FAILURE,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
+	retval = rtr_check_interval_option(&rtr_socket, RTR_INTERVAL_MODE_IGNORE_ON_FAILURE, pdu_eod.refresh_interval,
+					   RTR_INTERVAL_TYPE_REFRESH);
 	assert_int_equal(retval, RTR_SUCCESS);
 	assert_int_equal(rtr_socket.refresh_interval, 42);
 
 	rtr_socket.refresh_interval = 0;
 	pdu_eod.refresh_interval = RTR_REFRESH_MAX + 1;
-	retval = rtr_check_interval_option(
-			&rtr_socket,
-			RTR_INTERVAL_MODE_ACCEPT_ANY,
-			pdu_eod.refresh_interval,
-			RTR_INTERVAL_TYPE_REFRESH);
+	retval = rtr_check_interval_option(&rtr_socket, RTR_INTERVAL_MODE_ACCEPT_ANY, pdu_eod.refresh_interval,
+					   RTR_INTERVAL_TYPE_REFRESH);
 	assert_int_equal(retval, RTR_SUCCESS);
 	assert_int_equal(rtr_socket.refresh_interval, RTR_REFRESH_MAX + 1);
 }
@@ -502,25 +417,16 @@ static void test_set_interval_option(void **state)
 	struct rtr_socket rtr_socket;
 
 	rtr_set_interval_mode(&rtr_socket, RTR_INTERVAL_MODE_IGNORE_ANY);
-	assert_int_equal(
-			rtr_get_interval_mode(&rtr_socket),
-			RTR_INTERVAL_MODE_IGNORE_ANY);
+	assert_int_equal(rtr_get_interval_mode(&rtr_socket), RTR_INTERVAL_MODE_IGNORE_ANY);
 
 	rtr_set_interval_mode(&rtr_socket, RTR_INTERVAL_MODE_ACCEPT_ANY);
-	assert_int_equal(
-			rtr_get_interval_mode(&rtr_socket),
-			RTR_INTERVAL_MODE_ACCEPT_ANY);
+	assert_int_equal(rtr_get_interval_mode(&rtr_socket), RTR_INTERVAL_MODE_ACCEPT_ANY);
 
 	rtr_set_interval_mode(&rtr_socket, RTR_INTERVAL_MODE_DEFAULT_MIN_MAX);
-	assert_int_equal(
-			rtr_get_interval_mode(&rtr_socket),
-			RTR_INTERVAL_MODE_DEFAULT_MIN_MAX);
+	assert_int_equal(rtr_get_interval_mode(&rtr_socket), RTR_INTERVAL_MODE_DEFAULT_MIN_MAX);
 
-	rtr_set_interval_mode(
-			&rtr_socket, RTR_INTERVAL_MODE_IGNORE_ON_FAILURE);
-	assert_int_equal(
-			rtr_get_interval_mode(&rtr_socket),
-			RTR_INTERVAL_MODE_IGNORE_ON_FAILURE);
+	rtr_set_interval_mode(&rtr_socket, RTR_INTERVAL_MODE_IGNORE_ON_FAILURE);
+	assert_int_equal(rtr_get_interval_mode(&rtr_socket), RTR_INTERVAL_MODE_IGNORE_ON_FAILURE);
 
 	rtr_set_interval_mode(&rtr_socket, 4);
 	assert(rtr_get_interval_mode(&rtr_socket) != 4);
@@ -529,14 +435,10 @@ static void test_set_interval_option(void **state)
 int main(void)
 {
 	const struct CMUnitTest tests[] = {
-		cmocka_unit_test(test_set_last_update),
-		cmocka_unit_test(test_rtr_get_pdu_type),
-		cmocka_unit_test(test_pdu_to_network_byte_order),
-		cmocka_unit_test(test_pdu_to_host_byte_order),
-		cmocka_unit_test(test_rtr_pdu_check_size),
-		cmocka_unit_test(test_rtr_send_error_pdu),
-		cmocka_unit_test(test_rtr_pdu_check_interval),
-		cmocka_unit_test(test_set_interval_option),
+		cmocka_unit_test(test_set_last_update),		  cmocka_unit_test(test_rtr_get_pdu_type),
+		cmocka_unit_test(test_pdu_to_network_byte_order), cmocka_unit_test(test_pdu_to_host_byte_order),
+		cmocka_unit_test(test_rtr_pdu_check_size),	cmocka_unit_test(test_rtr_send_error_pdu),
+		cmocka_unit_test(test_rtr_pdu_check_interval),    cmocka_unit_test(test_set_interval_option),
 	};
 	return cmocka_run_group_tests(tests, NULL, NULL);
 }
